<?php

namespace SGalinski\SgJobs\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Extbase\DomainObject\AbstractEntity;

/**
 * The Job model
 */
class Job extends AbstractEntity {
	/**
	 * @var string $title
	 */
	protected $title = '';

	/**
	 * @var string $jobId
	 */
	protected $jobId = '';

	/**
	 * @var string $task
	 */
	protected $task = '';

	/**
	 * @var string $qualification
	 */
	protected $qualification = '';

	/**
	 * @var \SGalinski\SgJobs\Domain\Model\Department
	 */
	protected $department;

	/**
	 * @var bool
	 */
	protected $featuredOffer = FALSE;

	/**
	 * @var bool
	 */
	protected $hideApplyByEmail = TRUE;

	/**
	 * @var bool
	 */
	protected $hideApplyByPostal = TRUE;

	/**
	 * @var string $alternativeStartDate
	 */
	protected $alternativeStartDate = '';

	/**
	 * @var int $startDate
	 */
	protected $startDate = 0;

	/**
	 * @var int $sorting
	 */
	protected $sorting;

	/**
	 * @var \SGalinski\SgJobs\Domain\Model\Company $company
	 */
	protected $company = '';

	/**
	 * @var string $description
	 */
	protected $description = '';

	/**
	 * @var \SGalinski\SgJobs\Domain\Model\Contact $contact
	 */
	protected $contact;

	/**
	 * @var string $employmentTypes
	 */
	protected $employmentTypes = '';

	/**
	 * @var int $datePosted
	 */
	protected $datePosted = 0;

	/**
	 * @return string
	 */
	public function getTitle() {
		return $this->title;
	}

	/**
	 * @param string $title
	 */
	public function setTitle(string $title) {
		$this->title = $title;
	}

	/**
	 * @return string
	 */
	public function getJobId() {
		return $this->jobId;
	}

	/**
	 * @param string $jobId
	 */
	public function setJobId(string $jobId) {
		$this->jobId = $jobId;
	}

	/**
	 * @return string
	 */
	public function getTask() {
		return $this->task;
	}

	/**
	 * @param string $task
	 */
	public function setTask(string $task) {
		$this->task = $task;
	}

	/**
	 * @return string
	 */
	public function getQualification() {
		return $this->qualification;
	}

	/**
	 * @param string $qualification
	 */
	public function setQualification(string $qualification) {
		$this->qualification = $qualification;
	}

	/**
	 * @return int
	 */
	public function getStartDate() {
		return $this->startDate;
	}

	/**
	 * @param int $startDate
	 */
	public function setStartDate(int $startDate) {
		$this->startDate = $startDate;
	}

	/**
	 * @return Company
	 */
	public function getCompany() {
		return $this->company;
	}

	/**
	 * @param Company $company
	 */
	public function setCompany(Company $company) {
		$this->company = $company;
	}

	/**
	 * @return string
	 */
	public function getDescription() {
		return $this->description;
	}

	/**
	 * @param string $description
	 */
	public function setDescription(string $description) {
		$this->description = $description;
	}

	/**
	 * @return \SGalinski\SgJobs\Domain\Model\Contact
	 */
	public function getContact() {
		return $this->contact;
	}

	/**
	 * @param \SGalinski\SgJobs\Domain\Model\Contact $contact
	 */
	public function setContact(Contact $contact) {
		$this->contact = $contact;
	}

	/**
	 * @return Department|NULL
	 */
	public function getDepartment() {
		return $this->department;
	}

	/**
	 * @param Department $department
	 */
	public function setDepartment(Department $department) {
		$this->department = $department;
	}

	/**
	 * @return string
	 */
	public function getAlternativeStartDate() {
		return $this->alternativeStartDate;
	}

	/**
	 * @param string $alternativeStartDate
	 */
	public function setAlternativeStartDate(string $alternativeStartDate) {
		$this->alternativeStartDate = $alternativeStartDate;
	}

	/**
	 * @return bool
	 */
	public function isFeaturedOffer() {
		return $this->featuredOffer;
	}

	/**
	 * @param bool $featuredOffer
	 */
	public function setFeaturedOffer($featuredOffer) {
		$this->featuredOffer = $featuredOffer;
	}

	/**
	 * @return bool
	 */
	public function isHideApplyByEmail() {
		return $this->hideApplyByEmail;
	}

	/**
	 * @param bool $hideApplyByEmail
	 */
	public function setHideApplyByEmail($hideApplyByEmail) {
		$this->hideApplyByEmail = (boolean) $hideApplyByEmail;
	}

	/**
	 * @return bool
	 */
	public function isHideApplyByPostal() {
		return $this->hideApplyByPostal;
	}

	/**
	 * @param bool $hideApplyByPostal
	 */
	public function setHideApplyByPostal($hideApplyByPostal) {
		$this->hideApplyByPostal = (boolean) $hideApplyByPostal;
	}

	/**
	 * @return int
	 */
	public function getSorting(): int {
		return $this->sorting;
	}

	/**
	 * @param int $sorting
	 */
	public function setSorting(int $sorting): void {
		$this->sorting = $sorting;
	}

	/**
	 * @return string
	 */
	public function getEmploymentTypes(): string {
		return $this->employmentTypes;
	}

	/**
	 * @param string $employmentTypes
	 */
	public function setEmploymentTypes(string $employmentTypes): void {
		$this->employmentTypes = $employmentTypes;
	}

	/**
	 * @return int
	 */
	public function getDatePosted(): int {
		return $this->datePosted;
	}

	/**
	 * @param int $datePosted
	 */
	public function setDatePosted(int $datePosted): void {
		$this->datePosted = $datePosted;
	}
}
